From e340009fc59d59e59b2e8d903a884acb76b178eb Mon Sep 17 00:00:00 2001
From: Richard Linden <none@none>
Date: Fri, 9 Aug 2013 17:11:19 -0700
Subject: second phase summer cleaning replace llinfos, lldebugs, etc with new
 LL_INFOS(), LL_DEBUGS(), etc.

---
 indra/llmath/xform.cpp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'indra/llmath/xform.cpp')

diff --git a/indra/llmath/xform.cpp b/indra/llmath/xform.cpp
index b75aec6a27..5d8b93d5e8 100755
--- a/indra/llmath/xform.cpp
+++ b/indra/llmath/xform.cpp
@@ -36,10 +36,10 @@ LLXform::~LLXform()
 {
 }
 
 // Link optimization - don't inline these llwarns
 void LLXform::warn(const char* const msg)
 {
-	llwarns << msg << llendl;
+	LL_WARNS() << msg << LL_ENDL;
 }
 
 LLXform* LLXform::getRoot() const
@@ -36,10 +36,10 @@ LLXform::~LLXform()
 }
 
-// Link optimization - don't inline these llwarns
+// Link optimization - don't inline these LL_WARNS()
 void LLXform::warn(const char* const msg)
 {
-- 
cgit v1.2.3